# This is a library of utility codes with features to facilitate the development and programming of language model algorithms from Sapiens Technology®.
# All code here is the intellectual property of Sapiens Technology®, and any public mention, distribution, modification, customization, or unauthorized sharing of this or other codes from Sapiens Technology® will result in the author being legally punished by our legal team.
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------
from setuptools import setup, find_packages
package_name = 'utilities_nlp'
version = '4.0.5'
setup(
    name=package_name,
    version=version,
    author='SAPIENS TECHNOLOGY',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'TTS==0.22.0',
        'sapiens-transformers',
        'sapiens-infinite-context-window',
        'paddleocr==2.7.3',
        'paddlepaddle==2.6.0',
        'pillow==10.3.0',
        'cloudinary==1.40.0',
        'count-tokens==0.7.0',
        'tiktoken==0.4.0',
        'opencv-python==4.6.0.66',
        'opencv-python-headless==4.6.0.66',
        'ffmpeg-python==0.2.0',
        'gTTS==2.5.3',
        'pydub==0.25.1',
        'noisereduce==3.0.2',
        'yt-dlp==2025.10.22',
        'httpx<0.28.0',
        'youtube-search-python==1.6.6',
        'youtube-transcript-api==1.2.2',
        'moviepy==1.0.3',
        'certifi==2024.2.2',
        'beautifulsoup4==4.12.3',
        'numpy==1.25.2',
        'fasttext==0.9.3',
        'langid==1.1.6',
        'langdetect==1.0.9',
        'requests==2.31.0',
        'mutagen==1.47.0',
        'openai-whisper==20231117',
        'setuptools-rust==1.10.1',
        'fpdf==1.7.2',
        'reportlab==4.2.2',
        'python-docx==1.1.0',
        'docx==0.2.4',
        'openpyxl==3.1.3',
        'pandas==2.2.2',
        'XlsxWriter==3.2.0',
        'python-pptx==0.6.23',
        'matplotlib==3.9.1',
        'seaborn==0.13.2',
        'graphviz==0.20.3',
        'networkx==3.3',
        'wordcloud==1.9.3',
        'rembg==2.0.67',
        'onnxruntime==1.23.1',
        'super-image==0.2.0',
        'huggingface-hub==0.28.1'
    ],
    url='https://github.com/sapiens-technology/utilities_nlp',
    license='Proprietary Software'
)
# This is a library of utility codes with features to facilitate the development and programming of language model algorithms from Sapiens Technology®.
# All code here is the intellectual property of Sapiens Technology®, and any public mention, distribution, modification, customization, or unauthorized sharing of this or other codes from Sapiens Technology® will result in the author being legally punished by our legal team.
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------
